@@ -27,7 +27,7 @@ from praw.compat import (HTTPCookieProcessor,  # pylint: disable-msg=E0611
                          urljoin)
 from praw.settings import CONFIG
 
-__version__ = '1.0.12'
+__version__ = '1.0.13'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -61,8 +61,9 @@ class Config(object):  # pylint: disable-msg=R0903
                  'moderators':          'r/%s/about/moderators/',
                  'modqueue':            'r/%s/about/modqueue/',
                  'morechildren':        'api/morechildren/',
+                 'my_con_reddits':      'reddits/mine/contributor/',
                  'my_mod_reddits':      'reddits/mine/moderator/',
-                 'my_reddits':          'reddits/mine/',
+                 'my_reddits':          'reddits/mine/subscriber/',
                  'new':                 'new/',
                  'marknsfw':            'api/marknsfw/',
                  'popular_reddits':     'reddits/popular/',
@@ -269,7 +270,7 @@ class BaseReddit(object):
         :returns: a list of reddit content, of type Subreddit, Comment,
             Submission or user flair.
         """
-        content_found = 0
+        objects_found = 0
 
         if url_data is None:
             url_data = {}
@@ -282,7 +283,7 @@ class BaseReddit(object):
             fetch_all = False
 
         # While we still need to fetch more content to reach our limit, do so.
-        while fetch_all or content_found < limit:
+        while fetch_all or objects_found < limit:
             page_data = self.request_json(page_url, url_data=url_data)
             if root_field:
                 root = page_data[root_field]
@@ -290,9 +291,9 @@ class BaseReddit(object):
                 root = page_data
             for thing in root[thing_field]:
                 yield thing
-                content_found += 1
-                # Terminate when we reached the limit, or place holder
-                if (content_found == limit or
+                objects_found += 1
+                # Terminate when we've reached the limit, or place holder
+                if (objects_found == limit or
                     place_holder and thing.id == place_holder):
                     return
             # Set/update the 'after' parameter for the next iteration
@@ -394,13 +395,6 @@ class SubredditExtension(BaseReddit):
         return self.request_json(self.config['banned'] %
                                  six.text_type(subreddit))
 
-    @decorators.require_login
-    @decorators.require_moderator
-    def get_settings(self, subreddit):
-        """Get the settings for the given subreddit."""
-        return self.request_json(self.config['subreddit_settings'] %
-                                 six.text_type(subreddit))['data']
-
     @decorators.require_login
     @decorators.require_moderator
     def get_contributors(self, subreddit):
@@ -436,6 +430,13 @@ class SubredditExtension(BaseReddit):
                                 six.text_type(subreddit),
                                 limit=limit)
 
+    @decorators.require_login
+    @decorators.require_moderator
+    def get_settings(self, subreddit):
+        """Get the settings for the given subreddit."""
+        return self.request_json(self.config['subreddit_settings'] %
+                                 six.text_type(subreddit))['data']
+
     @decorators.require_login
     @decorators.require_moderator
     def get_spam(self, subreddit='mod', limit=None):
@@ -514,13 +515,14 @@ class SubredditExtension(BaseReddit):
                      prev_description_id=None,
                      prev_public_description_id=None, wikimode='disabled',
                      wiki_edit_age=30, wiki_edit_karma=100, **kwargs):
+        """Set the settings for the given subreddit."""
+
         # Temporary support for no longer valid entries
         if wiki_edit_age is None:
             wiki_edit_age = ''
         if wiki_edit_karma is None:
             wiki_edit_karma = ''
 
-        """Set the settings for the given subreddit."""
         params = {'r': six.text_type(subreddit),
                   'sr': subreddit.content_id,
                   'title': title,
@@ -537,7 +539,7 @@ class SubredditExtension(BaseReddit):
                   'domain_sidebar': 'on' if domain_sidebar else 'off',
                   'header-title': header_hover_text or '',
                   'wikimode': wikimode,
-                  'wiki_edit_age': six.text_type(wiki_edit_age ),
+                  'wiki_edit_age': six.text_type(wiki_edit_age),
                   'wiki_edit_karma': six.text_type(wiki_edit_karma)}
         if prev_description_id is not None:
             params['prev_description_id'] = prev_description_id
@@ -635,31 +637,6 @@ class LoggedInExtension(BaseReddit):
         helpers._request.evict(urls)  # pylint: disable-msg=E1101,W0212
         return response
 
-    @decorators.require_login
-    @decorators.RequireCaptcha
-    def send_message(self, recipient, subject, message, captcha=None):
-        """
-        Send a message to another redditor or a subreddit (mod mail).
-
-        When sending a message to a subreddit the recipient paramater must
-        either be a subreddit object or the subreddit name needs to be prefixed
-        with either '/r/' or '#'.
-        """
-        if isinstance(recipient, objects.Subreddit):
-            recipient = '/r/%s' % six.text_type(recipient)
-        else:
-            recipient = six.text_type(recipient)
-
-        params = {'text': message,
-                  'subject': subject,
-                  'to': recipient}
-        if captcha:
-            params.update(captcha)
-        response = self.request_json(self.config['compose'], params)
-        # pylint: disable-msg=E1101,W0212
-        helpers._request.evict([self.config['sent']])
-        return response
-
     @decorators.require_login
     @decorators.RequireCaptcha
     def compose_message(self, recipient, subject, message, captcha=None):
@@ -669,6 +646,7 @@ class LoggedInExtension(BaseReddit):
         Depreciated. compose_message has been renamed to send_message and will
         be removed in a future version.
         """
+        # Remove around the end of 2012
         warn('compose_message has been renamed to send_message and will be '
              'removed in a future version. Please update.', DeprecationWarning)
         return self.send_message(recipient, subject, message, captcha)
@@ -677,7 +655,7 @@ class LoggedInExtension(BaseReddit):
     def create_subreddit(self, name, title, description='', language='en',
                          subreddit_type='public', content_options='any',
                          over_18=False, default_set=True, show_media=False,
-                         domain=''):
+                         domain='', wikimode='disabled'):
         """Create a new subreddit."""
         params = {'name': name,
                   'title': title,
@@ -688,6 +666,7 @@ class LoggedInExtension(BaseReddit):
                   'over_18': 'on' if over_18 else 'off',
                   'allow_top': 'on' if default_set else 'off',
                   'show_media': 'on' if show_media else 'off',
+                  'wikimode': wikimode,
                   'domain': domain}
         return self.request_json(self.config['site_admin'], params)
 
@@ -732,6 +711,31 @@ class LoggedInExtension(BaseReddit):
         self.user = self.get_redditor(user)
         self.user.__class__ = objects.LoggedInRedditor
 
+    @decorators.require_login
+    @decorators.RequireCaptcha
+    def send_message(self, recipient, subject, message, captcha=None):
+        """
+        Send a message to another redditor or a subreddit (mod mail).
+
+        When sending a message to a subreddit the recipient paramater must
+        either be a subreddit object or the subreddit name needs to be prefixed
+        with either '/r/' or '#'.
+        """
+        if isinstance(recipient, objects.Subreddit):
+            recipient = '/r/%s' % six.text_type(recipient)
+        else:
+            recipient = six.text_type(recipient)
+
+        params = {'text': message,
+                  'subject': subject,
+                  'to': recipient}
+        if captcha:
+            params.update(captcha)
+        response = self.request_json(self.config['compose'], params)
+        # pylint: disable-msg=E1101,W0212
+        helpers._request.evict([self.config['sent']])
+        return response
+
 
 class Reddit(LoggedInExtension,  # pylint: disable-msg=R0904
              SubredditExtension):
